//
//  YHMsgViewController.swift
//  galaxy
//
//  Created by davidhuangA on 2024/4/7.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHMsgViewController: YHBaseViewController {
    
    var msgArr:[YHMessageInfoModel] = []
    lazy var viewModel = {
        let model = YHMsgViewModel()
        return model
    }()
    
    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.grouped)
        tableView.sectionHeaderHeight = 42.0
        tableView.estimatedSectionFooterHeight = 1.0
        tableView.showsVerticalScrollIndicator = false
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.backgroundColor = .white
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.backgroundView = emptyDataTipsView
        tableView.register(YHMessageSessionCell.self, forCellReuseIdentifier: YHMessageSessionCell.cellReuseIdentifier)
        return tableView
    }()
    
    lazy var navBar: YHCustomNavigationBar = {
        let bar = YHCustomNavigationBar.navBar()
        bar.backButton.isHidden = true
        bar.backgroundColor = .white
        bar.title = "消息"
        bar.showRightButtonType(.clean)
        bar.backBlock = {
            [weak self] in
            guard let self = self else { return }
            self.navigationController?.popViewController(animated: true)
        }
        bar.rightBtnClick = {
            [weak self] in
            guard let self = self else { return }
            YHCommonAlertView.show("清除未读", "确定要清除所有未读提示吗？", "取消", "确认") {
                let vc = YHInformationFillVC()
                vc.type = 1
                self.navigationController?.pushViewController(vc)
            }
        }
        return bar
    }()
    
    lazy var emptyDataTipsView:UIView = {
        let view = UIView(frame: CGRect(x: 0, y: 0, width: KScreenWidth, height: 124))
        view.isHidden = true
        let imgView = UIImageView(image: UIImage(named: "msg_no_data"))
        view.addSubview(imgView)
        
        let label = UILabel()
        label.textColor = UIColor(hex: 0x94A3B8)
        label.font = UIFont.PFSC_R(ofSize: 14)
        label.textAlignment = .center
        label.text = "暂无新消息".local
        view.addSubview(label)
        
        imgView.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(204)
            make.width.height.equalTo(92)
            make.centerX.equalTo(view)
        }
        
        label.snp.makeConstraints { make in
            make.top.equalTo(imgView.snp.bottom).offset(12)
            make.centerX.equalTo(view)
        }
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        getUnreadMsgList()
    }
    
    func setupUI() {
        
        gk_navigationBar.isHidden = true
        view.backgroundColor = .white
        view.addSubview(navBar)
        view.addSubview(tableView)
        navBar.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalToSuperview().offset(k_Height_statusBar())
            make.height.equalTo(k_Height_NavContentBar)
        }
        tableView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalToSuperview().offset(k_Height_NavigationtBarAndStatuBar)
            make.bottom.equalToSuperview().offset(-k_Height_TabBar)
        }
    }
    
    func getUnreadMsgList() {
        YHHUD.show(.progress(message: "加载中..."))
        self.viewModel.getUnreadMsgList {
            [weak self] success, error in
            guard let self = self else { return }
            YHHUD.hide()
            if success, let msgList = viewModel.msgList {
                msgArr.removeAll()
                // 资料填写
                if let infoMsg = msgList.information {
                    infoMsg.customType = .infoFill
                    msgArr.append(infoMsg)
                }
                // 证件上传
                if let cerMsg = msgList.certificate {
                    cerMsg.customType = .cerUpload
                    msgArr.append(cerMsg)
                }
                // 文书定稿
                if let dratMsg = msgList.draft {
                    dratMsg.customType = .draft
                    msgArr.append(dratMsg)
                }
                // 文件签字
                if let signMsg = msgList.signature {
                    signMsg.customType = .fileSign
                    msgArr.append(signMsg)
                }
                self.tableView.reloadData()
            }
        }
    }
}

extension YHMsgViewController {
    
    @objc func clean() {
        
    }
    
    @objc func didEnableNotifyBtnClicked() {
        
    }
}

extension YHMsgViewController: UITableViewDelegate, UITableViewDataSource {

    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return msgArr.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCell(withIdentifier: YHMessageSessionCell.cellReuseIdentifier, for: indexPath) as! YHMessageSessionCell
        if 0 <= indexPath.row && indexPath.row < msgArr.count {
            let model = msgArr[indexPath.row]
            cell.updateModel(model)
        }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 76.0
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
       
        if 0 < indexPath.row && indexPath.row < msgArr.count {
            let msgItem = msgArr[indexPath.row]
            let vc = YHInformationFillVC()
            vc.type = msgItem.type
            self.navigationController?.pushViewController(vc)
        }
    }

    private func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> CGFloat {
        return 42.0
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 1.0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        
        let view = UIView()
        view.backgroundColor = UIColor(hex: 0x3570DC, alpha: 0.06)
        
        let label = UILabel()
        label.textColor = UIColor(hex: 0x121A26)
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:13)
        label.text = "开启通知，及时掌握最新消息".local
        view.addSubview(label)
        
        let enableBtn = UIButton()
        enableBtn.setTitle("开启".local, for: .normal)
        enableBtn.setTitleColor(UIColor(hex: 0x3570DC), for: .normal)
        enableBtn.titleLabel?.font = .PFSC_R(ofSize: 13)
        enableBtn.YH_clickEdgeInsets = UIEdgeInsets(top: 12, left: 20, bottom: 12, right: 20)
        enableBtn.addTarget(self, action: #selector(didEnableNotifyBtnClicked), for: .touchUpInside)
        view.addSubview(enableBtn)

        label.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalTo(enableBtn.snp.left).offset(-20)
            make.centerY.equalToSuperview()
        }
        enableBtn.snp.makeConstraints { make in
            make.size.equalTo(CGSize(width: 26, height: 18))
            make.right.equalToSuperview().offset(-20)
            make.centerY.equalToSuperview()
        }
        return view
    }
}
